@@ -952,72 +952,6 @@ loadConstraints <- function(object, pool, item_attrib, st_attrib = NULL, file =
   return(out)
 }
 
-#' Toggle constraints
-#'
-#' \code{\link{toggleConstraints}} is a function to toggle individual constraints in a \code{\linkS4class{constraints}} object.
-#'
-#' @param object a \code{\linkS4class{constraints}} object from \code{\link{loadConstraints}}.
-#' @param on constraint indices to mark as active.
-#' @param off constraint indices to mark as inactive.
-#'
-#' @return \code{\link{toggleConstraints}} returns the updated \code{\linkS4class{constraints}} object.
-#'
-#' @examples
-#' constraints_science2 <- toggleConstraints(constraints_science, off = 32:36)
-#' constraints_science3 <- toggleConstraints(constraints_science, on = 32:36)
-#'
-#' @export
-toggleConstraints <- function(object, on = NULL, off = NULL) {
-
-  nc <- nrow(object@constraints)
-  if (length(intersect(on, off)) > 0) {
-    stop("toggleConstraints: 'on' and 'off' must have no values in common")
-  }
-  if (!"ONOFF" %in% names(object@constraints)) {
-    object@constraints[["ONOFF"]] <- ""
-  }
-  if (!is.null(on)) {
-    if (any(!is.element(on, 1:nc))) {
-      stop(sprintf("toggleConstraints: 'on' should be within c(1:nc), nc = %s", nc))
-    }
-    for (index in on) {
-      object@list_constraints[[index]]@suspend <- FALSE
-      object@constraints[index, "ONOFF"] <- ""
-    }
-  }
-  if (!is.null(off)) {
-    if (any(!is.element(off, 1:nc))) {
-      stop(sprintf("toggleConstraints: 'off' should be within c(1:nc), nc = %s", nc))
-    }
-    for (index in off) {
-      object@list_constraints[[index]]@suspend <- TRUE
-      object@constraints[index, "ONOFF"] <- "OFF"
-    }
-  }
-
-  index <- NULL
-  mat   <- NULL
-  dir   <- NULL
-  rhs   <- NULL
-
-  for (i in 1:nc) {
-    if (object@constraints[["TYPE"]][i] != "ORDER" && !object@list_constraints[[i]]@suspend) {
-      object@list_constraints[[i]]@nc <- nrow(object@list_constraints[[i]]@mat)
-      mat   <- rbind(mat, object@list_constraints[[i]]@mat)
-      dir   <- c(dir, object@list_constraints[[i]]@dir)
-      rhs   <- c(rhs, object@list_constraints[[i]]@rhs)
-      index <- c(index, rep(object@list_constraints[[i]]@constraint, object@list_constraints[[i]]@nc))
-    }
-  }
-
-  object@index <- index
-  object@mat   <- mat
-  object@dir   <- dir
-  object@rhs   <- rhs
-
-  return(object)
-}
-
 #' Build constraints (shortcut to other loading functions)
 #'
 #' \code{\link{buildConstraints}} is a data loading function to create a \code{\linkS4class{constraints}} object.
